<?php

/**
 * Einrichtungstermine.class.php
 *
 * Einrichtungstermine: Kalender für alle Termine einer Einrichtung
 * 
 * @package	RFT
 *
 * @author	Henning Voss, vosshe@fh-trier.de
 * @author	David Klober, kloberd@fh-trier.de
 * @author	Marcus Haberkorn, haberkorn@fh-trier.de
 * @mail	elearning@fh-trier.de
 * @copyright	RFT 2006-2010
 */


require_once ("lib/language.inc.php");
require_once ("config/config.inc.php");
require_once ("lib/datei.inc.php");
require_once ("lib/visual.inc.php");
require_once ("lib/functions.php");
require_once ("classes/TermineDB.class.php");
require_once "include/config.inc.php";

class Einrichtungstermine extends AbstractStudIPStandardPlugin
{
    var $inst_id = "";
    private $template_factory;

    function Einrichtungstermine()
    {
        AbstractStudIPStandardPlugin::AbstractStudIPStandardPlugin();
        $this->template_factory = new Flexi_TemplateFactory(dirname(__FILE__).'/templates');
		global $SessSemName;
		$this->inst_id = (!empty($_GET["cid"]) ? $_GET["cid"] : (empty($SessSemName[1]) ? $_GET["auswahl"] : $SessSemName[1])); // TODO nicht sehr sauber
		if(!$this->checkInstitutID($this->inst_id))
		{
			$this->inst_id = NULL;
			return;
		}
        $user = $this->getUser();
        $perm = $user->getPermission();
        $this->showNavigation();

        $this->setPluginiconname("img/groupfile.gif");
        $this->overview = true;
    }
    
    function checkInstitutID()
    {
        if(empty($this->inst_id))
			return false;
		else 
		{
			$db = new DB_Seminar;
			$sql = "SELECT COUNT(*) c FROM Institute WHERE Institut_id = '%s'";
			$db->queryf($sql, $this->inst_id);
			if($db->next_record() && $db->f("c") != 0)
				return true;
			else
				return false;
		}
    }
	
    function showNavigation()
    {
		if(!empty($this->inst_id))
		{
			$nav = new PluginNavigation();
			$nav->setDisplayname(_("Einrichtungstermine"));
			$nav->setCommand("viewMonth");
			
			$navDay = new PluginNavigation();
			$navDay->setDisplayname(_("Tagesansicht"));
			$navDay->setCommand("viewDay");
			$nav->addSubmenu($navDay);		
			
			$navWeek = new PluginNavigation();
			$navWeek->setDisplayname(_("Wochenansicht"));
			$navWeek->setCommand("viewWeek");
			$nav->addSubmenu($navWeek);

			$navMonth = new PluginNavigation();
			$navMonth->setDisplayname(_("Monatsansicht"));
			$navMonth->setCommand("viewMonth");
			$nav->addSubmenu($navMonth);

			$this->setNavigation($nav);
		}		    
    }

    function hasChanged($lastlogin)
    {
        return true;
    }

    function getPluginname()
    {
        return _("Einrichtungstermine");
    } 

    function prepareUninstallation()
    {
    }
    
    function getDate()
    {
		try{
			if(!empty($_POST["jmp_d"]) && !empty($_POST["jmp_m"]) && !empty($_POST["jmp_y"]))
				$date = mktime(0, 0, 0, intval($_POST["jmp_m"]), intval($_POST["jmp_d"]), intval($_POST["jmp_y"]));
			else if(empty($_GET["date"]))
				$date = (empty($_SESSION["institut_termine_plugin_date"]) ? time() : $_SESSION["institut_termine_plugin_date"]);
			else
				$date = intval($_GET["date"]);
		}catch(Exception $ex){
			$date = (empty($_SESSION["institut_termine_plugin_date"]) ? time() : $_SESSION["institut_termine_plugin_date"]);
		}
		$_SESSION["institut_termine_plugin_date"] = $date;
		return $date;
    }

    function actionviewday()
    {
		if(!$this->checkInstitutID($this->inst_id))
            return;
            
        $date = $this->getDate();
		$first_day_of_month = mktime(0, 0, 0, idate('m', $date), 1, idate('Y', $date));
        $template = $this->template_factory->open('day_view');
		$template->set_attribute('inst_id', $this->inst_id);
		$template->set_attribute('user_id', $this->user->userid);
		$template->set_attribute('day_link', $this->getLink("viewDay"));
		$template->set_attribute('week_link', $this->getLink("viewWeek"));
		$template->set_attribute('month_link', $this->getLink("viewMonth"));
        $template->set_attribute('date', $date);
        $template->set_attribute('first_day_of_month', $first_day_of_month);
        $template->set_attribute('title_calendar', Calendar::$MONATE[idate('m', $date)] . date(" Y", $date));
        $template->set_attribute('title', Calendar::$TAGE[idate('w', $date)] . date(", d. ", $date) . Calendar::$MONATE[idate('m', $date)] . date(" Y", $date));
	
		// Zeitfenster zur Anzeige
		$day_begin = Calendar::$VIEWPORTS["DAY_BEGIN"];
		$day_end = Calendar::$VIEWPORTS["DAY_END"];
	 
		if($day_begin < 0 || $day_begin > 24 )
			$day_begin = 0;

		if($day_end < 0 || $day_end > 24 || $day_end < $day_begin) 
			$day_end = 24;

		$template->set_attribute('day_begin', $day_begin);
		$template->set_attribute('day_end', $day_end);

		$terms = array();
        echo $template->render();
    }
    
    function actionviewweek()
    {
		if(!$this->checkInstitutID($this->inst_id))
            return;
        $date = $this->getDate();
		$day_of_week = idate('w', $date);
		
		if($day_of_week == 0) 
			$day_of_week = 6;
		else
			$day_of_week--;
			
		$first_day_of_week = $date - ($day_of_week) * 60 * 60 * 24;
		$last_day_of_week = $date + (6 - $day_of_week) * 60 * 60 * 24;
		$days = array($first_day_of_week);
		
		for($i = 1; $i < 7; $i++)
			$days []= $first_day_of_week + 60 * 60 * 24 * $i;
			
        $template = $this->template_factory->open('week_view');
		$template->set_attribute('inst_id', $this->inst_id);
		$template->set_attribute('user_id', $this->user->userid);
		$template->set_attribute('day_link', $this->getLink("viewDay"));
		$template->set_attribute('week_link', $this->getLink("viewWeek"));
		$template->set_attribute('month_link', $this->getLink("viewMonth"));
        $template->set_attribute('date', $date);
		$template->set_attribute('days', $days);
        $template->set_attribute('title', date("W.", $date) . " Woche vom " . date("d.m.Y", $first_day_of_week) . " bis " . date("d.m.Y", $last_day_of_week));
        
        // Zeitfenster zur Anzeige
		$week_begin = Calendar::$VIEWPORTS["WEEK_BEGIN"];
		$week_end = Calendar::$VIEWPORTS["WEEK_END"];
	 
		if($week_begin < 0 || $week_begin > 24 )
			$week_begin = 0;

		if($week_end < 0 || $week_end > 24 || $week_end < $week_begin) 
			$week_end = 24;

		$template->set_attribute('week_begin', $week_begin);
		$template->set_attribute('week_end', $week_end);
             
        echo $template->render();
    }
    
    function actionviewmonth()
    {
		if(!$this->checkInstitutID($this->inst_id))
            return;
        $date = $this->getDate();
		$first_day_of_month = mktime(0, 0, 0, idate('m', $date), 1, idate('Y', $date));
        $template = $this->template_factory->open('month_view');
		$template->set_attribute('inst_id', $this->inst_id);
		$template->set_attribute('user_id', $this->user->userid);
		$template->set_attribute('day_link', $this->getLink("viewDay"));
		$template->set_attribute('week_link', $this->getLink("viewWeek"));
		$template->set_attribute('month_link', $this->getLink("viewMonth"));
        $template->set_attribute('date', $date);
        $template->set_attribute('first_day_of_month', $first_day_of_month);
        $template->set_attribute('title', Calendar::$MONATE[idate("m", $date)] . date(" Y", $date));
		
		echo $template->render();
    }
    
    private function getLink($param)
    {
        $link = PluginEngine::getLink($this, array(), $param); // TODO das geht bestimmt besser
		if(!strchr($link, "?"))
			return $link . "?x=x";
		else
			return $link;
    }
}
?>
