<?php

/**
 * Termin.class.php
 *
 * Einrichtungstermine: Kalender für alle Termine einer Einrichtung
 * 
 * @package	RFT
 *
 * @author	Henning Voss, vosshe@fh-trier.de
 * @author	David Klober, kloberd@fh-trier.de
 * @author	Marcus Haberkorn, haberkorn@fh-trier.de
 * @mail	elearning@fh-trier.de
 * @copyright	RFT 2006-2010
 */

class Termin
{
    var $id;
    var $description;
    var $date;
    var $seminar_id;

    function Termin(&$row)
    {
        $this->id = $row->f("termin_id");
        $this->description = $row->f("description");
        $this->date = $row->f("date");
		$this->end = $row->f("end_time");
		$this->seminar_id = $row->f("range_id");
    }
    
    public function &getSeminar()
    {
		return TermineDB::getSeminar($this->seminar_id);
    }

    public function getDate()
    {
        return $date;
    }
    
    public function getURL()
    {
        return "/details.php?sem_id=" . $this->seminar_id;
    }
    
    public function getShortTitle()
    {
        return $this->getTitle();
    }
    
    public function getTitle()
    {
        $seminar = $this->getSeminar();
		return $seminar["name"];
    }
    
    public function getTimeTitle()
    {
        return date("H:i", $this->date) . "-" . date("H:i", $this->end);
    }
    
    public function isInTimeSlot($start, $end)
    {
        return ($this->date >= $start && $this->date <= $end) || ($this->end >= $start && $this->date <= $end);
    }
    
    public static function cmp($term_a, $term_b)
    {
		return ($term_a->date > $term_b->date ? -1 : 1);
    }

    public static function sort(&$terms_of_day)
    {
        usort($terms_of_day, array("Termin", "cmp"));
		return $terms_of_day;
    }

    public static function &orderTermsOfDay(&$terms_of_day, $day, $ticks)
    {
        if(count($terms_of_day) <= 0)
			return NULL;
			
        $tick_size = 24 * 60 / $ticks;
		$tick = 0;
		$result = array();
		$max_terms_per_tick = 0;
		$day_offset = mktime(0, 0, 0, idate('m', $day), idate('d', $day), idate('Y', $day));
		for($i = 0; $i < 24 * 60; $i = $i + $tick_size)
		{
			$tick_result = array();
			foreach($terms_of_day as $term)
			{
				if($term->isInTimeSlot($day_offset + ($i * 60) + 1, $day_offset + ($i + $tick_size) * 60 - 1))
				{
					$tick_result []= $term;
				}
			}
			if(count($tick_result) > $max_terms_per_tick)
				$max_terms_per_tick = count($tick_result); 
				
			$result []= $tick_result;
		}
		$result["max_terms_day"] = $max_terms_per_tick;
		
        return $result;
    } 
    
    public static function getNumberOfSlots(&$terms_of_day, $term_id)
    {
        $result = 0;
        foreach($terms_of_day as $slot)
		{
			if($slot != NULL && is_array($slot))
				foreach($slot as $term)
					if($term->id == $term_id)
						$result++;
		}
		return $result;
    }
    
    public static function isFirstSlot(&$terms_of_day, $term_id, $slot)
    {
        if($slot == 0)
	    return true;
	    
        foreach($terms_of_day[$slot - 1] as $term)
		{
			if($term->id == $term_id)
				return false;
		}
        return true;
    }
}
?>
